Species
==================

The :any:`Species` class is the generic class for all species.
:any:`Electron` and :any:`Proton` are the short cuts for the most common species.

.. automodule:: lambdapic.core.species
   :member-order: bysource
   :members:
   :undoc-members: Species
   :show-inheritance:
